==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/misc/MonitorConverter.h <==
// public class soot.dava.toolkits.base.misc.MonitorConverter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f947baf2d989bed5 soot_dava_toolkits_base_misc_MonitorConverter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_misc_MonitorConverter_H_
#define _JC_soot_dava_toolkits_base_misc_MonitorConverter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_refs	_jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_nonrefs	_jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$refs	_jc_soot_dava_toolkits_base_misc_MonitorConverter$refs;
typedef struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$nonrefs	_jc_soot_dava_toolkits_base_misc_MonitorConverter$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object	_jc_soot_dava_toolkits_base_misc_MonitorConverter$object;

typedef const struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vmethods	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vtable	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vtable;
typedef const struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vtype	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_misc_MonitorConverter$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_dava_toolkits_base_misc_MonitorConverter$method$convert$79338b70c5bb1713(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object *, struct _jc_soot_dava_DavaBody$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_misc_MonitorConverter$method_info$convert$79338b70c5bb1713;

// Static methods
extern struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object *_jc_soot_dava_toolkits_base_misc_MonitorConverter$method$v$0193f4a555d173e6(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vmethods {
	void	(*convert$79338b70c5bb1713)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object *, struct _jc_soot_dava_DavaBody$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vmethods	soot_dava_toolkits_base_misc_MonitorConverter;
};

// Vtype
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_refs {
	struct _jc_soot_SootMethod$object	*v;
	struct _jc_soot_SootMethod$object	*enter;
	struct _jc_soot_SootMethod$object	*exit;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$refs {
    _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_refs	soot_dava_toolkits_base_misc_MonitorConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_nonrefs	soot_dava_toolkits_base_misc_MonitorConverter;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object {
	_jc_soot_dava_toolkits_base_misc_MonitorConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vtype	*vtype;
	_jc_soot_dava_toolkits_base_misc_MonitorConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_misc_MonitorConverter$vtype _jc_soot_dava_toolkits_base_misc_MonitorConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_misc_MonitorConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_misc_MonitorConverter$class_object;

#endif	/* _JC_soot_dava_toolkits_base_misc_MonitorConverter_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/misc/MonitorConverter.h <==
// public class soot.dava.toolkits.base.misc.MonitorConverter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f947baf2d989bed5 soot_dava_toolkits_base_misc_MonitorConverter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_misc_MonitorConverter_H_
#define _JC_soot_dava_toolkits_base_misc_MonitorConverter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_refs	_jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_nonrefs	_jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$refs	_jc_soot_dava_toolkits_base_misc_MonitorConverter$refs;
typedef struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$nonrefs	_jc_soot_dava_toolkits_base_misc_MonitorConverter$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object	_jc_soot_dava_toolkits_base_misc_MonitorConverter$object;

typedef const struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vmethods	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vtable	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vtable;
typedef const struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vtype	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_misc_MonitorConverter$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_toolkits_base_misc_MonitorConverter$method$convert$79338b70c5bb1713(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object *, struct _jc_soot_dava_DavaBody$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_misc_MonitorConverter$method_info$convert$79338b70c5bb1713;

// Static methods
extern struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object *_jc_soot_dava_toolkits_base_misc_MonitorConverter$method$v$0193f4a555d173e6(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vmethods {
	void	(*convert$79338b70c5bb1713)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object *, struct _jc_soot_dava_DavaBody$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vmethods	soot_dava_toolkits_base_misc_MonitorConverter;
};

// Vtype
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_refs {
	struct _jc_soot_SootMethod$object	*v;
	struct _jc_soot_SootMethod$object	*enter;
	struct _jc_soot_SootMethod$object	*exit;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$refs {
    _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_refs	soot_dava_toolkits_base_misc_MonitorConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_misc_MonitorConverter$sub_nonrefs	soot_dava_toolkits_base_misc_MonitorConverter;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_misc_MonitorConverter$object {
	_jc_soot_dava_toolkits_base_misc_MonitorConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_misc_MonitorConverter$vtype	*vtype;
	_jc_soot_dava_toolkits_base_misc_MonitorConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_misc_MonitorConverter$vtype _jc_soot_dava_toolkits_base_misc_MonitorConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_misc_MonitorConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_misc_MonitorConverter$class_object;

#endif	/* _JC_soot_dava_toolkits_base_misc_MonitorConverter_H_ */
